@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Document::OpenAPI;
 # ABSTRACT: One OpenAPI v3.0, v3.1 or v3.2 document
 # KEYWORDS: JSON Schema data validation request response OpenAPI
 
-our $VERSION = '0.115';
+our $VERSION = '0.116';
 
 use 5.020;
 use utf8;
@@ -26,7 +26,7 @@ use Digest::MD5 'md5_hex';
 use Storable 'dclone';
 use builtin::compat qw(blessed indexed);
 use MooX::TypeTiny 0.002002;
-use Types::Standard qw(HashRef ArrayRef Str);
+use Types::Standard qw(HashRef ArrayRef Str Map Any);
 use namespace::clean;
 
 extends 'JSON::Schema::Modern::Document';
@@ -87,6 +87,11 @@ has path_templates => (
   isa => ArrayRef[Str],
 );
 
+has defaults => (
+  is => 'rwp',
+  isa => Map[json_pointer_type, Any],
+);
+
 # we define the sub directly, rather than using an 'around', since our root base class is not
 # Moo::Object, so we never got a BUILDARGS to modify
 sub BUILDARGS ($class, @args) {
@@ -331,6 +336,8 @@ sub traverse ($self, $evaluator, $config_override = {}) {
     return $state;
   }
 
+  $self->_set_defaults($result->defaults) if $result->defaults;
+
   ()= E({ %$state, keyword_path => $_ }, '"items" must be present if type is "array"')
     foreach @bad_items_paths;
 
@@ -496,7 +503,10 @@ sub traverse ($self, $evaluator, $config_override = {}) {
 # that as part of traverse.
 sub validate ($class, @args) {
   my $document = blessed($class) ? $class : $class->new(@args);
-  return JSON::Schema::Modern::Result->new(valid => !$document->has_errors, errors => [ $document->errors ]);
+  return JSON::Schema::Modern::Result->new(
+    errors => [ $document->errors ],
+    $document->defaults ? (defaults => $document->defaults) : (),
+  );
 }
 
 ######## NO PUBLIC INTERFACES FOLLOW THIS POINT ########
@@ -615,7 +625,7 @@ JSON::Schema::Modern::Document::OpenAPI - One OpenAPI v3.0, v3.1 or v3.2 documen
 
 =head1 VERSION
 
-version 0.115
+version 0.116
 
 =head1 SYNOPSIS
 
@@ -764,6 +774,12 @@ Returns the list of json pointer location(s) of operations that use the provided
 
 All path templates under C</paths/>, sorted in canonical search order.
 
+=head2 defaults
+
+A hashref, mapping json pointer locations in the instance data to the default value assigned
+to the property at this location, taken from C<default> keywords in the metaschema under
+C<properties> and C<patternProperties> keywords.
+
 =head1 SEE ALSO
 
 =over 4
